/****************************************************************************************
*  YAROCK                                                                               *
*  Copyright (c) 2010-2013 Sebastien amardeilh <sebastien.amardeilh+yarock@gmail.com>   *
*                                                                                       *
*  This program is free software; you can redistribute it and/or modify it under        *
*  the terms of the GNU General Public License as published by the Free Software        *
*  Foundation; either version 2 of the License, or (at your option) any later           *
*  version.                                                                             *
*                                                                                       *
*  This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
*  PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
*                                                                                       *
*  You should have received a copy of the GNU General Public License along with         *
*  this program.  If not, see <http://www.gnu.org/licenses/>.                           *
*****************************************************************************************/

#ifndef _COVER_TASK_
#define _COVER_TASK_

#include "coverprovider.h"

#include <QStringList>
#include <QObject>
#include <QByteArray>
#include <QMap>

/*
********************************************************************************
*                                                                              *
*    Class CoverTask                                                           *
*                                                                              *
********************************************************************************
*/
class CoverTask : public QObject
{
Q_OBJECT
 public:
    explicit CoverTask(QObject *parent = 0);
    ~CoverTask();
    void setExit(bool b) {m_exit = b;}
    void setRequest(const QString& artist, const QString& album);

    bool isRunning() {return m_isRunning;};
    void start();

  private slots:
    void slot_check_database();
    void slot_process_cover_search();
    void slot_start_cover_provider();
    void slot_finish_cover_search();
    void slot_save_cover(int, QByteArray);
    void slot_cover_provider_search_finished();

  private:
    struct RequestParam
    {
      RequestParam(){};

      QString artist;
      QString album;
      QString cover_path;
    };

    bool                   m_isRunning;
    QMap<int, RequestParam>  m_map_params;

    RequestParam           m_current_param;
    int                    m_current_request_id;
    
    int                    m_max;
    bool                   m_exit;

    //! perform search on all missing cover or on specific request
    bool                   m_isFullDbSearch;

    QList<CoverProvider*>  m_coverprovider_list;
    int                    m_current_provider_id;

  signals:
    void finished();
    void progress(int);
};


#endif // _COVER_TASK_
