/****************************************************************************************
*  YAROCK                                                                               *
*  Copyright (c) 2010-2013 Sebastien amardeilh <sebastien.amardeilh+yarock@gmail.com>   *
*                                                                                       *
*  This program is free software; you can redistribute it and/or modify it under        *
*  the terms of the GNU General Public License as published by the Free Software        *
*  Foundation; either version 2 of the License, or (at your option) any later           *
*  version.                                                                             *
*                                                                                       *
*  This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
*  PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
*                                                                                       *
*  You should have received a copy of the GNU General Public License along with         *
*  this program.  If not, see <http://www.gnu.org/licenses/>.                           *
*****************************************************************************************/

#include "collectionscene.h"
#include "playqueue/virtual_playqueue.h"
#include "models/local/collectionmodel.h"
#include "models/local/plsfilemodel.h"
#include "models/local/histomodel.h"

#include "core/mediaitem/mediaitem.h"
#include "smartplaylist/smartplaylist.h"

#include "debug.h"

#include <QGraphicsItem>
/*
********************************************************************************
*                                                                              *
*    Class CollectionScene                                                     *
*        -> playing method                                                     *
********************************************************************************
*/
void CollectionScene::playAlbum()
{
    Debug::debug() << "CollectionScene::playAlbum";
    if(!m_mouseGrabbedItem) return;
    AlbumGraphicItem *item = static_cast<AlbumGraphicItem*>(m_mouseGrabbedItem);

    QList<MEDIA::TrackPtr> tracks = _collectionModel->getItemChildrenTracks(item->media);

    if(!tracks.isEmpty())
      VirtualPlayqueue::instance()->addTracksAndPlayAt(tracks, 0);
}

void CollectionScene::playAlbumGenre()
{
    Debug::debug() << "CollectionScene::playAlbumGenre";
    if(!m_mouseGrabbedItem) return;
    AlbumGenreGraphicItem *item = static_cast<AlbumGenreGraphicItem*>(m_mouseGrabbedItem);

    QList<MEDIA::TrackPtr> tracks = _collectionModel->getAlbumChildrenTracksGenre(item->media,item->_genre);

    if(!tracks.isEmpty())
      VirtualPlayqueue::instance()->addTracksAndPlayAt(tracks, 0);
}

void CollectionScene::playArtist()
{
    Debug::debug() << "CollectionScene::playArtist";
    if(!m_mouseGrabbedItem) return;
    ArtistGraphicItem *item = static_cast<ArtistGraphicItem*>(m_mouseGrabbedItem);

    QList<MEDIA::TrackPtr> tracks = _collectionModel->getItemChildrenTracks(item->media);

    if(!tracks.isEmpty())
      VirtualPlayqueue::instance()->addTracksAndPlayAt(tracks, 0);
}


void CollectionScene::playTrack()
{
    Debug::debug() << "CollectionScene::playTrack";
    if(!m_mouseGrabbedItem) return;
    TrackGraphicItem *item = static_cast<TrackGraphicItem*>(m_mouseGrabbedItem);

    QList<MEDIA::TrackPtr> tracks;
    /* ------ tracks from  TRACK VIEW  ------ */
    if(m_view_mode == MAIN::ViewTrack)
    {
      tracks = _collectionModel->getItemChildrenTracks(_collectionModel->rootItem());
    }
    /* ------ tracks from  PLAYLIST VIEW  ------ */
    else if(m_view_mode == MAIN::ViewPlaylist)
    {
      tracks = _plsFileModel->getItemChildrenTracks(_plsFileModel->rootItem());
    }
    /* ------ tracks from  HISTORY VIEW  ------ */
    else if(m_view_mode == MAIN::ViewHistory)
    {
        for ( int i = 0; i < _histoModel->itemCount(); i++ ) {
          if(!_histoModel->isItemFiltered(i))
            continue;
          tracks << _histoModel->trackAt(i);
        }
    }

    int index = tracks.indexOf(item->media);
    if( index != -1 && !tracks.isEmpty() )
      VirtualPlayqueue::instance()->addTracksAndPlayAt(tracks, index);
}

void CollectionScene::playPlaylist()
{
    if(!m_mouseGrabbedItem) return;
    PlaylistGraphicItem *item = static_cast<PlaylistGraphicItem*>(m_mouseGrabbedItem);

    QList<MEDIA::TrackPtr> tracks;

    // rechercher dynamique pour les smart playlists
    if(item->media->p_type == T_SMART)
    {
      tracks = SmartPlaylist::mediaItem( item->media->rules );
    }
    // playliste normale -> lecture dans le modele
    else {
      tracks = _plsFileModel->getItemChildrenTracks(item->media);
    }

    if(!tracks.isEmpty())
      VirtualPlayqueue::instance()->addTracksAndPlayAt(tracks,0);
}

void CollectionScene::playSelected()
{
    //Debug::debug() << "CollectionScene::playSelected";

    QList<MEDIA::TrackPtr> tracks;

    QList<QGraphicsItem*> selected_items = sortedSelectedItem();

    foreach(QGraphicsItem* gi, selected_items)
    {
      if (gi->type() == GraphicsItem::AlbumType)
      {
        AlbumGraphicItem *item = static_cast<AlbumGraphicItem *>(gi);
        tracks << _collectionModel->getItemChildrenTracks(item->media);
      }
      else if (gi->type() == GraphicsItem::AlbumGenreType)
      {
       AlbumGenreGraphicItem *item = static_cast<AlbumGenreGraphicItem*>(gi);
       tracks << _collectionModel->getAlbumChildrenTracksGenre(item->media,item->_genre);
      }
      else if (gi->type() == GraphicsItem::ArtistType)
      {
        ArtistGraphicItem *item = static_cast<ArtistGraphicItem*>(gi);
        tracks << _collectionModel->getItemChildrenTracks(item->media);
      }
      else if (gi->type() == GraphicsItem::TrackType)
      {
        TrackGraphicItem *item = static_cast<TrackGraphicItem*>(gi);
        tracks << _collectionModel->getItemChildrenTracks(item->media);
      }
      else if (gi->type() == GraphicsItem::PlaylistType)
      {
        PlaylistGraphicItem *item = static_cast<PlaylistGraphicItem*>(gi);

        // rechercher dynamique pour les smart playlists
        if(item->media->p_type == T_SMART)
          tracks << SmartPlaylist::mediaItem( item->media->rules );
        // playliste normale -> lecture dans le modele
        else
        tracks << _plsFileModel->getItemChildrenTracks(item->media);
      }
    } // end foreach

    if(!tracks.isEmpty())
      VirtualPlayqueue::instance()->addTracksAndPlayAt(tracks,0);
}

