/****************************************************************************************
*  YAROCK                                                                               *
*  Copyright (c) 2010-2013 Sebastien amardeilh <sebastien.amardeilh+yarock@gmail.com>   *
*                                                                                       *
*  This program is free software; you can redistribute it and/or modify it under        *
*  the terms of the GNU General Public License as published by the Free Software        *
*  Foundation; either version 2 of the License, or (at your option) any later           *
*  version.                                                                             *
*                                                                                       *
*  This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
*  PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
*                                                                                       *
*  You should have received a copy of the GNU General Public License along with         *
*  this program.  If not, see <http://www.gnu.org/licenses/>.                           *
*****************************************************************************************/

//! local
#include "menuwidget.h"
#include "menumodel.h"
#include "global_actions.h"
#include "yarocksettings.h"

#include "debug.h"

//! Qt
#include <QVBoxLayout>
#include <QApplication>
#include <QPainter>
#include <QMenu>

/*
********************************************************************************
*                                                                              *
*    Class MenuWidget                                                          *
*                                                                              *
********************************************************************************
*/
MenuWidget::MenuWidget(QWidget * parent) : QWidget(parent)
{
    m_parent = parent;
    
    QPalette palette = QApplication::palette();
    palette.setColor(QPalette::Background, palette.color(QPalette::Base));
    this->setPalette(palette);

    this->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
    
        
    /*  navigator bar  */
    m_menuBar = new MenuBar(this);
    m_menuBar->setModel( MenuModel::instance() );

    /*  navigator tree  */    
    m_menu_view = new MenuView(MenuModel::instance(), this);
    
    /*  stacked widget */    
    stackedWidget = new QStackedWidget;
    stackedWidget->addWidget(m_menu_view);
    stackedWidget->addWidget(m_menuBar);
     
    QVBoxLayout* verticalLayout = new QVBoxLayout(this);
    verticalLayout->setSpacing(0);
    verticalLayout->setContentsMargins(0, 0, 0, 0);
    verticalLayout->addWidget(stackedWidget);
    
    this->setLayout(verticalLayout);
    
    /* action */
    ACTIONS()->insert(APP_SHOW_MENU_TREE, new QAction(QIcon(),tr("show extended menu"), this));    
    ACTIONS()->value(APP_SHOW_MENU_TREE)->setCheckable(true);
 
    ACTIONS()->value(APP_SHOW_MENU_TREE)->setChecked(!SETTINGS()->_is_menu_bar);

    connect(ACTIONS()->value(APP_SHOW_MENU_TREE), SIGNAL(triggered()), this, SLOT(slot_change_menu_style()));
    

    stackedWidget->setCurrentIndex(SETTINGS()->_is_menu_bar ? 1 : 0);
}


MenuView* MenuWidget::menuView()
{
  return m_menu_view;
}

void MenuWidget::contextMenuEvent ( QContextMenuEvent * event )
{
    QMenu *m = new QMenu(this);
    m->addAction(ACTIONS()->value(APP_SHOW_MENU_TREE));

    m->popup(mapToGlobal(event->pos()));
    //m->deleteLater;
}

void MenuWidget::slot_change_menu_style (  )
{
    int idx = stackedWidget->currentIndex();
    
    QList<int> widths = m_splitter->sizes();

    int w_menu    = widths.at(0);
    int w_browser = widths.at(1);

    
    if(idx==0)
    {
      stackedWidget->setCurrentIndex(1);
      m_menuBar->resize(50, this->height());
   
      w_browser += w_menu -50;
    
      QList<int> list;
      list << 50 << w_browser << widths.at(2);
      m_splitter->setSizes (list);
      
      SETTINGS()->_is_menu_bar = true;
    }
    else 
    {
      stackedWidget->setCurrentIndex(0);
      
      w_browser += w_menu - 180;

      QList<int> list;
      list << 180 << w_browser << widths.at(2);
      m_splitter->setSizes (list);       

      SETTINGS()->_is_menu_bar = false;
    }
}



